<a id="autonomy.fsm.scaffold.templates.tests"></a>

# autonomy.fsm.scaffold.templates.tests

Templates for FSM tests

<a id="autonomy.fsm.scaffold.templates.tests.TEST_ROUNDS"></a>

## TEST`_`ROUNDS Objects

```python
@dataclass
class TEST_ROUNDS()
```

Template for test_rounds.py

<a id="autonomy.fsm.scaffold.templates.tests.TEST_BEHAVIOURS"></a>

## TEST`_`BEHAVIOURS Objects

```python
@dataclass
class TEST_BEHAVIOURS()
```

Template for test_behaviours.py

<a id="autonomy.fsm.scaffold.templates.tests.TEST_PAYLOADS"></a>

## TEST`_`PAYLOADS Objects

```python
@dataclass
class TEST_PAYLOADS()
```

Template for test_payloads.py

<a id="autonomy.fsm.scaffold.templates.tests.TEST_MODELS"></a>

## TEST`_`MODELS Objects

```python
@dataclass
class TEST_MODELS()
```

Template for test_models.py

<a id="autonomy.fsm.scaffold.templates.tests.TEST_HANDLERS"></a>

## TEST`_`HANDLERS Objects

```python
@dataclass
class TEST_HANDLERS()
```

Template for test_handlers.py

<a id="autonomy.fsm.scaffold.templates.tests.TEST_DIALOGUES"></a>

## TEST`_`DIALOGUES Objects

```python
@dataclass
class TEST_DIALOGUES()
```

Template for test_dialogues.py

